# import_resolve
[![Build Status](https://travis-ci.org/PandaWhoCodes/import_resolve.svg?branch=master)](https://travis-ci.org/PandaWhoCodes/import_resolve)

Resolves pip imports in a python project

## Installation
\
`pip install import_resolve`


## Usage

 * import_resolve /python_project_folder